package eGuideDog::Browser::InputText;

use strict;
use warnings;
use eGuideDog::Browser::Const;
use eGuideDog::Basic;
use Curses;
use vars qw(@ISA);
require eGuideDog::Browser::Widget;
@ISA = qw(eGuideDog::Browser::Widget);

sub new;
sub text;
sub press;
sub screen;

sub new {
  my ($class, $callback, $caption, $text) = @_;

  my $self = $class->SUPER::new($callback);
  bless $self, __PACKAGE__;
  if ($caption) {
    $self->caption($caption);
  } else {
    $self->caption(gettext('Please enter text: '));
  }
  if ($text) {
    $self->text($text);
  } else {
    $self->text('');
  }
  return $self;
}

sub text {
  my ($self, $text) = @_;
  $self->{text} = $text if ($text);
  return $self->{text};
}

sub screen {
  my ($self) = @_;
  if (!defined $self->{screen}) {
    my @buffer;
    push(@buffer, $self->{caption});
    push(@buffer, $self->{text});
    $self->{screen} = eGuideDog::Terminal::Buffer->new(\@buffer);
  }
  return $self->{screen};
}

sub press {
  my ($self, $key) = @_;

  # printable char ' ' == 32, '~' == 126,
  if (length($key) == 1 && $key le '~' && $key ge ' ') {
    $self->{text} .= $key;
    $self->{screen}->{lines}->[1] = $self->{text};
    $self->{screen}->update(1);
  }

  # backspace
  elsif ($key eq KEY_BACKSPACE) {
    chop($self->{text});
    $self->{screen}->{lines}->[1] = $self->{text};
    $self->{screen}->update(1);
  }

  # Enter key, commit
  elsif ($key eq "\n") {
    &{$self->{callback}}($self->{text});
  }

  # unknown key, throw it
  else {
    return eGuideDog::Browser::Const::THROW_KEY;
  }

  return eGuideDog::Browser::Const::CATCH_KEY;
}

1;
